@@ -5,7 +5,7 @@ import logging
 # model classes that may be implemented externally
 from .supplier.model import (
     DataSpec, ValueSupplierInterface, Distribution, CasterInterface, RecordProcessor, OutputHandlerInterface,
-    ResettableIterator)
+    ResettableIterator, KeyProviderInterface)
 # programmatic spec building
 from . import builder
 # expose this at root too
@@ -16,8 +16,8 @@ from .registries import Registry as registry
 from .exceptions import SpecException, ResourceError
 from .supplier.exceptions import SupplierException
 # commonly used by client code
-from .loader import field_loader, Loader
-from . import suppliers, distributions, outputs
+from .loader import preprocess_and_format, field_loader, Loader
+from . import suppliers, distributions, outputs, utils
 # to trigger registered functions
 from . import cli
 
